==> haskell-json-0.10-212-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 json
version:              0.10
visibility:           public
id:                   json-0.10-FDPGsXzpLW1HTCsmwVxFpW
key:                  json-0.10-FDPGsXzpLW1HTCsmwVxFpW
license:              BSD-3-Clause
copyright:            (c) 2007-2018 Galois Inc.
maintainer:           Iavor S. Diatchki (iavor.diatchki@gmail.com)
author:               Galois Inc.
synopsis:             Support for serialising Haskell to and from JSON
description:
    JSON (JavaScript Object Notation) is a lightweight data-interchange
    format. It is easy for humans to read and write. It is easy for
    machines to parse and generate.  It is based on a subset of the
    JavaScript Programming Language, Standard ECMA-262 3rd Edition -
    December 1999.

    This library provides a parser and pretty printer for converting
    between Haskell values and JSON.

category:             Web
abi:                  b40606747394ce4694a439897908b1f1
exposed:              True
exposed-modules:
    Text.JSON Text.JSON.Generic Text.JSON.Pretty Text.JSON.ReadP
    Text.JSON.String Text.JSON.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/json-0.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/json-0.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/json-0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-json
hs-libraries:         HSjson-0.10-FDPGsXzpLW1HTCsmwVxFpW
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    mtl-2.2.2 pretty-1.1.3.6 syb-0.7.2.4-3MUyG3p3euQLeyQ65NE0AP
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-json/html/json.haddock
haddock-html:         /usr/share/doc/haskell-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-json-0.10-214-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 json
version:              0.10
visibility:           public
id:                   json-0.10-DRBuvbQyt9L7OQ7mtzYh9P
key:                  json-0.10-DRBuvbQyt9L7OQ7mtzYh9P
license:              BSD-3-Clause
copyright:            (c) 2007-2018 Galois Inc.
maintainer:           Iavor S. Diatchki (iavor.diatchki@gmail.com)
author:               Galois Inc.
synopsis:             Support for serialising Haskell to and from JSON
description:
    JSON (JavaScript Object Notation) is a lightweight data-interchange
    format. It is easy for humans to read and write. It is easy for
    machines to parse and generate.  It is based on a subset of the
    JavaScript Programming Language, Standard ECMA-262 3rd Edition -
    December 1999.

    This library provides a parser and pretty printer for converting
    between Haskell values and JSON.

category:             Web
abi:                  9ec83d9c968f61480a9088a88d86fb3d
exposed:              True
exposed-modules:
    Text.JSON Text.JSON.Generic Text.JSON.Pretty Text.JSON.ReadP
    Text.JSON.String Text.JSON.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/json-0.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/json-0.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/json-0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-json
hs-libraries:         HSjson-0.10-DRBuvbQyt9L7OQ7mtzYh9P
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    mtl-2.2.2 pretty-1.1.3.6 syb-0.7.3-L4OhoYbUcQQ8vXL0yfxnA4
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-json/html/json.haddock
haddock-html:         /usr/share/doc/haskell-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
